@@ -1,5 +1,5 @@
-from core.fair_os import FairOs
-from core.base_obj import FairBase
+from .core.fair_os import FairOs
+from .core.base_obj import FairBase
 
 class FairFS(FairBase):
      
